# Workflow: Task-to-Agent Mapping

Use these agents proactively — no user prompt needed.

| Task | Agent |
|------|-------|
| After any Python code change | `python-reviewer` |
| New feature or bug fix | `tdd-guide` |
| Build / `make check` failure | `build-error-resolver` |
| Plugin config, secrets, auth | `security-reviewer` |
| Dead code, refactoring | `refactor-cleaner` |
| Render pipeline, ffmpeg filters | `ffmpeg-expert` |
| `.ass` overlays, subtitle templates | `ass-subtitle-expert` |
| OBS plugin / scripting | `obs-studio-expert` |
| YouTube uploads / API | `youtube-api-expert` |
| Meta / Instagram / Threads API | `meta-api-expert` |
| Complex feature planning | `planner` |
| Architectural decisions | `architect` |
